==> one_target_mobile_sdk-0.0.11.tar.gz: example/lib/screens/tracking/advancedTracking/customer_screen.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk/one_target_mobile_sdk.dart';
import 'package:one_target_mobile_sdk_example/common/constant.dart';
import 'package:one_target_mobile_sdk_example/common/utils.dart';
import 'package:one_target_mobile_sdk_example/screens/tracking/advancedTracking/payment_detail_screen.dart';

class CustomerScreen extends StatefulWidget {
  const CustomerScreen({Key? key}) : super(key: key);

  @override
  State<CustomerScreen> createState() => _CustomerScreenState();
}

class _CustomerScreenState extends State<CustomerScreen> {
  bool _isChecked = false;
  final TextEditingController _tecFirstName = TextEditingController();
  final TextEditingController _tecLastName = TextEditingController();
  final TextEditingController _tecDob = TextEditingController();
  final TextEditingController _tecCodeVjSkyClub = TextEditingController();
  final TextEditingController _tecAddress = TextEditingController();
  final TextEditingController _tecEmail = TextEditingController();
  final TextEditingController _tecPhoneNumber = TextEditingController();
  bool _isTracking = false;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          children: [
            const SizedBox(height: 16.0),
            const SizedBox(height: 16.0),
            Align(
              alignment: Alignment.center,
              child: Utils.getText(
                "Ai sẽ bay",
                32,
                FontWeight.w500,
                Colors.black,
              ),
            ),
            const SizedBox(height: 16.0),
            Expanded(
              child: Container(
                decoration: BoxDecoration(
                  border: Border.all(
                    width: 1.0,
                    color: Colors.grey,
                  ),
                  borderRadius: const BorderRadius.all(Radius.circular(0)),
                ),
                child: ListView(
                  padding: EdgeInsets.zero,
                  physics: const BouncingScrollPhysics(),
                  children: [
                    Utils.getTitle("Hành khách"),
                    Container(
                      padding: const EdgeInsets.all(16.0),
                      child: Column(
                        children: [
                          Row(
                            children: [
                              Expanded(
                                child: Utils.getButton(
                                  "Ông",
                                  14.0,
                                  Colors.black,
                                  Colors.white,
                                  const Icon(Icons.unfold_more),
                                  () {},
                                ),
                              ),
                              const SizedBox(width: 16.0),
                              Expanded(
                                child: Container(),
                              ),
                            ],
                          ),
                          const SizedBox(height: 16.0),
                          Row(
                            children: [
                              Expanded(
                                child: Utils.getTextInput(
                                  "Họ",
                                  TextInputType.text,
                                  _tecFirstName,
                                ),
                              ),
                              const SizedBox(width: 16.0),
                              Expanded(
                                child: Utils.getTextInput(
                                  "Tên đệm và tên",
                                  TextInputType.text,
                                  _tecLastName,
                                ),
                              ),
                            ],
                          ),
                          const SizedBox(height: 16.0),
                          Row(
                            children: [
                              Expanded(
                                child: Utils.getTextInput(
                                  "Ngày sinh",
                                  TextInputType.datetime,
                                  _tecDob,
                                ),
                              ),
                              const SizedBox(width: 16.0),
                              Expanded(
                                child: Container(),
                              ),
                            ],
                          ),
                          const SizedBox(height: 16.0),
                          Utils.getTextInput(
                            "Mã thành viên VietJet Skyclub",
                            TextInputType.text,
                            _tecCodeVjSkyClub,
                          ),
                          const SizedBox(height: 16.0),
                          Utils.getTextInput(
                            "Địa chỉ",
                            TextInputType.text,
                            _tecAddress,
                          ),
                          const SizedBox(height: 16.0),
                          Row(
                            children: [
                              Expanded(
                                child: Utils.getButton(
                                  "Thành phố/Tỉnh",
                                  14.0,
                                  Colors.black,
                                  Colors.white,
                                  const Icon(Icons.unfold_more),
                                  () {},
                                ),
                              ),
                              const SizedBox(width: 16.0),
                              Expanded(
                                child: Utils.getButton(
                                  "Quốc tịch",
                                  14.0,
                                  Colors.black,
                                  Colors.white,
                                  const Icon(Icons.unfold_more),
                                  () {},
                                ),
                              ),
                            ],
                          ),
                          const SizedBox(height: 16.0),
                          Utils.getTextInput(
                            "Email",
                            TextInputType.emailAddress,
                            _tecEmail,
                          ),
                          const SizedBox(height: 16.0),
                          Row(
                            children: [
                              Flexible(
                                flex: 2,
                                child: Utils.getButton(
                                  "+84",
                                  14.0,
                                  Colors.black,
                                  Colors.white,
                                  const Icon(Icons.unfold_more),
                                  () {},
                                ),
                              ),
                              const SizedBox(width: 16.0),
                              Flexible(
                                flex: 3,
                                child: Utils.getTextInput(
                                  "Số điện thoại",
                                  TextInputType.number,
                                  _tecPhoneNumber,
                                ),
                              ),
                            ],
                          ),
                          const SizedBox(height: 16.0),
                          Row(
                            children: [
                              Checkbox(
                                activeColor: Colors.red,
                                tristate: false,
                                value: _isChecked,
                                onChanged: (value) {
                                  setState(() {
                                    if (value != null) {
                                      _isChecked = value;
                                    }
                                  });
                                },
                              ),
                              Expanded(
                                child: Utils.getText(
                                  "Tôi muốn nhận thông tin khuyến mãi từ công ty",
                                  12.0,
                                  FontWeight.w400,
                                  Colors.black,
                                ),
                              ),
                            ],
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ),
            const SizedBox(height: 16.0),
            Utils.getButton(
              "Tiếp theo",
              16.0,
              Colors.white,
              _isTracking ? Colors.grey : Colors.deepPurple,
              null,
              () {
                _trackEvent();
              },
            ),
            const SizedBox(height: 16.0),
          ],
        ),
      ),
    );
  }

  void _trackEvent() {
    if (_isTracking) {
      return;
    }
    setState(() {
      _isTracking = true;
    });
    var profile = <Map>[];
    profile.add({
      "index": 1,
      "full_name": "${_tecFirstName.text} ${_tecLastName.text}",
      "gender": "Male",
      "address": _tecAddress.text,
      // "skyclub": "hoangkim2512",
      "skyclub": _tecCodeVjSkyClub.text,
      "city": "Hồ Chí Minh",
      "country": "Viet Nam",
      "email": _tecEmail.text,
      "phone": _tecPhoneNumber.text,
      "Unsubscribed from emails": "False",
    });
    // profile.add({
    //   "index": 2,
    //   "full_name": "Nguyễn Văn A",
    //   "gender": "Male",
    //   "address": "45A Nguyễn Thị Minh Khai, phường 3, quận 3",
    //   "skyclub": "hoangkim2512",
    //   "city": "Hồ Chí Minh",
    //   "country": "Viet Nam",
    //   "email": "example@gmail.com",
    //   "phone": "123123123"
    // });
    G1SDK.trackEvent(
      Constant.getWorkSpaceId(),
      {
        "screen": "CustomerScreen",
      },
      profile,
      "input_passenger_info",
      DateTime.now().millisecondsSinceEpoch,
      {
        "ecommerce.trip_type": "roundTrip",
        "ecommerce.trip_route": "SGN-HN",
        "ecommerce.value": _tecCodeVjSkyClub.text,
        // "ecommerce.value": "hoangkim2512",
        "profile.0.full_name": "${_tecFirstName.text} ${_tecLastName.text}",
        // "profile.0.full_name": "Nguyễn Văn A",
        "profile.0.gender": "Male",
        "profile.0.address": _tecAddress.text,
        // "profile.0.address": "45A Nguyễn Thị Minh Khai, phường 3, quận 3",
        "profile.0.city": "Ho Chi Minh",
        "profile.0.country": "Vietnam",
        "profile.0.unsubscribed_from_emails": "false",
        "profile.0.email": _tecEmail.text,
        // "profile.0.email": "example@gmail.com",
        "profile.0.phone": _tecPhoneNumber.text,
        // "profile.0.phone": "123123123",
      },
      onResponse: (value) {
        Utils.log(">>>onResponse $value");
        Get.to(() => const PaymentDetailScreen());
        setState(() {
          _isTracking = false;
        });
      },
      onFailure: (value) {
        Utils.log(">>>onFailure $value");
        setState(() {
          _isTracking = false;
        });
      },
    );
  }
}

==> one_target_mobile_sdk-0.0.15.tar.gz: example/lib/screens/tracking/advancedTracking/customer_screen.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:one_target_mobile_sdk/one_target_mobile_sdk.dart';
import 'package:one_target_mobile_sdk_example/common/constant.dart';
import 'package:one_target_mobile_sdk_example/common/utils.dart';
import 'package:one_target_mobile_sdk_example/screens/tracking/advancedTracking/payment_detail_screen.dart';

class CustomerScreen extends StatefulWidget {
  const CustomerScreen({Key? key}) : super(key: key);

  @override
  State<CustomerScreen> createState() => _CustomerScreenState();
}

class _CustomerScreenState extends State<CustomerScreen> {
  bool _isChecked = false;
  final TextEditingController _tecFirstName = TextEditingController();
  final TextEditingController _tecLastName = TextEditingController();
  final TextEditingController _tecDob = TextEditingController();
  final TextEditingController _tecCodeVjSkyClub = TextEditingController();
  final TextEditingController _tecAddress = TextEditingController();
  final TextEditingController _tecEmail = TextEditingController();
  final TextEditingController _tecPhoneNumber = TextEditingController();
  bool _isTracking = false;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Colors.white,
        elevation: 0,
        leading: IconButton(
          icon: const Icon(Icons.arrow_back_ios, color: Colors.black),
          onPressed: () {
            Get.back();
          },
        ),
        actions: [
          Utils.getDebugViewIcon(),
        ],
        centerTitle: true,
        title: const Text(''),
      ),
      body: Container(
        padding: const EdgeInsets.all(16.0),
        child: Column(
          children: [
            const SizedBox(height: 16.0),
            const SizedBox(height: 16.0),
            Align(
              alignment: Alignment.center,
              child: Utils.getText(
                "Ai sẽ bay",
                32,
                FontWeight.w500,
                Colors.black,
              ),
            ),
            const SizedBox(height: 16.0),
            Expanded(
              child: Container(
                decoration: BoxDecoration(
                  border: Border.all(
                    width: 1.0,
                    color: Colors.grey,
                  ),
                  borderRadius: const BorderRadius.all(Radius.circular(0)),
                ),
                child: ListView(
                  padding: EdgeInsets.zero,
                  physics: const BouncingScrollPhysics(),
                  children: [
                    Utils.getTitle("Hành khách"),
                    Container(
                      padding: const EdgeInsets.all(16.0),
                      child: Column(
                        children: [
                          Row(
                            children: [
                              Expanded(
                                child: Utils.getButton(
                                  "Ông",
                                  14.0,
                                  Colors.black,
                                  Colors.white,
                                  const Icon(Icons.unfold_more),
                                  () {},
                                ),
                              ),
                              const SizedBox(width: 16.0),
                              Expanded(
                                child: Container(),
                              ),
                            ],
                          ),
                          const SizedBox(height: 16.0),
                          Row(
                            children: [
                              Expanded(
                                child: Utils.getTextInput(
                                  "Họ",
                                  TextInputType.text,
                                  _tecFirstName,
                                ),
                              ),
                              const SizedBox(width: 16.0),
                              Expanded(
                                child: Utils.getTextInput(
                                  "Tên đệm và tên",
                                  TextInputType.text,
                                  _tecLastName,
                                ),
                              ),
                            ],
                          ),
                          const SizedBox(height: 16.0),
                          Row(
                            children: [
                              Expanded(
                                child: Utils.getTextInput(
                                  "Ngày sinh",
                                  TextInputType.datetime,
                                  _tecDob,
                                ),
                              ),
                              const SizedBox(width: 16.0),
                              Expanded(
                                child: Container(),
                              ),
                            ],
                          ),
                          const SizedBox(height: 16.0),
                          Utils.getTextInput(
                            "Mã thành viên VietJet Skyclub",
                            TextInputType.text,
                            _tecCodeVjSkyClub,
                          ),
                          const SizedBox(height: 16.0),
                          Utils.getTextInput(
                            "Địa chỉ",
                            TextInputType.text,
                            _tecAddress,
                          ),
                          const SizedBox(height: 16.0),
                          Row(
                            children: [
                              Expanded(
                                child: Utils.getButton(
                                  "Thành phố/Tỉnh",
                                  14.0,
                                  Colors.black,
                                  Colors.white,
                                  const Icon(Icons.unfold_more),
                                  () {},
                                ),
                              ),
                              const SizedBox(width: 16.0),
                              Expanded(
                                child: Utils.getButton(
                                  "Quốc tịch",
                                  14.0,
                                  Colors.black,
                                  Colors.white,
                                  const Icon(Icons.unfold_more),
                                  () {},
                                ),
                              ),
                            ],
                          ),
                          const SizedBox(height: 16.0),
                          Utils.getTextInput(
                            "Email",
                            TextInputType.emailAddress,
                            _tecEmail,
                          ),
                          const SizedBox(height: 16.0),
                          Row(
                            children: [
                              Flexible(
                                flex: 2,
                                child: Utils.getButton(
                                  "+84",
                                  14.0,
                                  Colors.black,
                                  Colors.white,
                                  const Icon(Icons.unfold_more),
                                  () {},
                                ),
                              ),
                              const SizedBox(width: 16.0),
                              Flexible(
                                flex: 3,
                                child: Utils.getTextInput(
                                  "Số điện thoại",
                                  TextInputType.number,
                                  _tecPhoneNumber,
                                ),
                              ),
                            ],
                          ),
                          const SizedBox(height: 16.0),
                          Row(
                            children: [
                              Checkbox(
                                activeColor: Colors.red,
                                tristate: false,
                                value: _isChecked,
                                onChanged: (value) {
                                  setState(() {
                                    if (value != null) {
                                      _isChecked = value;
                                    }
                                  });
                                },
                              ),
                              Expanded(
                                child: Utils.getText(
                                  "Tôi muốn nhận thông tin khuyến mãi từ công ty",
                                  12.0,
                                  FontWeight.w400,
                                  Colors.black,
                                ),
                              ),
                            ],
                          ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            ),
            const SizedBox(height: 16.0),
            Utils.getButton(
              "Tiếp theo",
              16.0,
              Colors.white,
              _isTracking ? Colors.grey : Colors.deepPurple,
              null,
              () {
                _trackEvent();
              },
            ),
            const SizedBox(height: 16.0),
          ],
        ),
      ),
    );
  }

  void _trackEvent() {
    if (_isTracking) {
      return;
    }
    setState(() {
      _isTracking = true;
    });
    var profile = <Map>[];
    var numberPhone = '+84${_tecPhoneNumber.text}';
    profile.add({
      "index": 1,
      "full_name": "${_tecFirstName.text} ${_tecLastName.text}",
      "gender": "Male",
      "address": _tecAddress.text,
      "skyclub": _tecCodeVjSkyClub.text,
      "city": "Hồ Chí Minh",
      "country": "Viet Nam",
      "email": _tecEmail.text,
      "phone": numberPhone,
      "Unsubscribed from emails": "False",
    });
    G1SDK.instance.trackEvent(
      Constant.getWorkSpaceId(),
      {},
      profile,
      "input_passenger_info",
      DateTime.now().millisecondsSinceEpoch,
      {
        "ecommerce.trip_type": "roundTrip",
        "ecommerce.trip_route": "SGN-HN",
        "ecommerce.value": _tecCodeVjSkyClub.text,
        // "ecommerce.value": "hoangkim2512",
        "profile.0.full_name": "${_tecFirstName.text} ${_tecLastName.text}",
        // "profile.0.full_name": "Nguyễn Văn A",
        "profile.0.gender": "Male",
        "profile.0.address": _tecAddress.text,
        // "profile.0.address": "45A Nguyễn Thị Minh Khai, phường 3, quận 3",
        "profile.0.city": "Ho Chi Minh",
        "profile.0.country": "Vietnam",
        "profile.0.unsubscribed_from_emails": "false",
        "profile.0.email": _tecEmail.text,
        // "profile.0.email": "example@gmail.com",
        "profile.0.phone": numberPhone,
        // "profile.0.phone": "123123123",
      },
      onResponse: (value) {
        Utils.log(">>>onResponse $value");
        Get.to(() => const PaymentDetailScreen());
        setState(() {
          _isTracking = false;
        });
      },
      onFailure: (value) {
        Utils.log(">>>onFailure $value");
        setState(() {
          _isTracking = false;
        });
      },
    );
  }
}
